[Libreoffice-commits] online.git: 4 commits - kit/Kit.cpp loleaflet/src

Marco Cecchetti (via logerrit) logerrit at kemper.freedesktop.org
Thu Oct 3 18:06:58 UTC 2019


 kit/Kit.cpp                      |    6 +++++-
 loleaflet/src/control/Toolbar.js |   23 ++++++++++++++++++++---
 2 files changed, 25 insertions(+), 4 deletions(-)

New commits:
commit 22b2c100884e7da94f844380e5cb834d088a0ecb
Author:     Marco Cecchetti <mrcekets at gmail.com>
AuthorDate: Tue Jul 2 12:47:06 2019 +0200
Commit:     Michael Meeks <michael.meeks at collabora.com>
CommitDate: Thu Oct 3 19:05:48 2019 +0100

    loleaflet: disable triple tab on map when user opens the about dialog
    
    It has been reported cases where having the triple tab event handler
    enabled on map prevents the about dialog to receive the same event.
    
    Change-Id: I73b81acde9372f464b302f479f7920b159d34931

diff --git a/loleaflet/src/control/Toolbar.js b/loleaflet/src/control/Toolbar.js
index 78166da3c..cd0728b69 100644
--- a/loleaflet/src/control/Toolbar.js
+++ b/loleaflet/src/control/Toolbar.js
@@ -313,6 +313,11 @@ L.Map.include({
 			afterOpen: function() {
 				var that = this;
 
+				var touchGesture = map['touchGesture'];
+				if (touchGesture && touchGesture._hammer) {
+					touchGesture._hammer.off('tripletap', L.bind(touchGesture._onTripleTap, touchGesture));
+				}
+
 				var $vexContent = $(this.contentEl);
 				var hammer = new Hammer.Manager($vexContent.get(0));
 				hammer.add(new Hammer.Tap({ taps: 3 }));
@@ -332,7 +337,11 @@ L.Map.include({
 				});
 			},
 			beforeClose: function () {
-				$(window).unbind('keyup.vex', handler)
+				$(window).unbind('keyup.vex', handler);
+				var touchGesture = map['touchGesture'];
+				if (touchGesture && touchGesture._hammer) {
+					touchGesture._hammer.on('tripletap', L.bind(touchGesture._onTripleTap, touchGesture));
+				}
 				map.enable(true);
 				map.focus();
 			}
commit 9cb8785ae4b9c4598ad641733ca6ec549d535c58
Author:     Michael Meeks <michael.meeks at collabora.com>
AuthorDate: Thu Jun 27 12:06:43 2019 +0100
Commit:     Michael Meeks <michael.meeks at collabora.com>
CommitDate: Thu Oct 3 19:05:14 2019 +0100

    Use the right method to toggle debug layers on and off on tripple click.
    
    Change-Id: Ibcfaf33eb0beb826aee8e9e60df4ad0017490423

diff --git a/loleaflet/src/control/Toolbar.js b/loleaflet/src/control/Toolbar.js
index dd05dfbb0..78166da3c 100644
--- a/loleaflet/src/control/Toolbar.js
+++ b/loleaflet/src/control/Toolbar.js
@@ -317,7 +317,7 @@ L.Map.include({
 				var hammer = new Hammer.Manager($vexContent.get(0));
 				hammer.add(new Hammer.Tap({ taps: 3 }));
 				hammer.on('tap', function() {
-					map._docLayer._debugInit();
+					map._docLayer.toggleTileDebugMode();
 				});
 
 				this.contentEl.style.width = w + 'px';
commit 788485424bbb529f34a6a407eb193c372ff2467d
Author:     Szymon Kłos <szymon.klos at collabora.com>
AuthorDate: Wed Jun 19 16:19:34 2019 +0200
Commit:     Michael Meeks <michael.meeks at collabora.com>
CommitDate: Thu Oct 3 19:05:10 2019 +0100

    Enable debug mode on 3 taps in about dialog
    
    Change-Id: I33c5ed240080e2827ec8d6d4581e073d05f73290

diff --git a/kit/Kit.cpp b/kit/Kit.cpp
index 2a26b7118..eb3f006b7 100644
--- a/kit/Kit.cpp
+++ b/kit/Kit.cpp
@@ -2114,11 +2114,15 @@ public:
         }
         catch (const std::exception& exc)
         {
-            LOG_ERR("QueueHandler::run: Exception: " << exc.what());
+            LOG_FTL("QueueHandler::run: Exception: " << exc.what());
+            Log::shutdown();
+            std::_Exit(Application::EXIT_SOFTWARE);
         }
         catch (...)
         {
             LOG_FTL("QueueHandler::run: Unknown exception");
+            Log::shutdown();
+            std::_Exit(Application::EXIT_SOFTWARE);
         }
     }
 


More information about the Libreoffice-commits mailing list
diff --git a/loleaflet/src/control/Toolbar.js b/loleaflet/src/control/Toolbar.js
index b57bb7dc4..dd05dfbb0 100644
--- a/loleaflet/src/control/Toolbar.js
+++ b/loleaflet/src/control/Toolbar.js
@@ -3,7 +3,7 @@
  * Toolbar handler
  */
 
 /* global $ window vex sanitizeUrl brandProductName brandProductURL _ */
 L.Map.include({
 
 	// a mapping of uno commands to more readable toolbar items
@@ -312,8 +312,16 @@ L.Map.include({
 			buttons: {},
 			afterOpen: function() {
 				var that = this;
-				this.contentEl.style.width = w + 'px';
+
 				var $vexContent = $(this.contentEl);
+				var hammer = new Hammer.Manager($vexContent.get(0));
+				hammer.add(new Hammer.Tap({ taps: 3 }));
+				hammer.on('tap', function() {
+					map._docLayer._debugInit();
+				});
+
+				this.contentEl.style.width = w + 'px';
+
 				map.enable(false);
 				$(window).bind('keyup.vex', handler);
 				// workaround for https://github.com/HubSpot/vex/issues/43
@@ -3,7 +3,7 @@
  */
 
-/* global $ window vex sanitizeUrl brandProductName brandProductURL _ */
+/* global $ window vex sanitizeUrl brandProductName brandProductURL _ Hammer */
 L.Map.include({
 
commit 5e0e6006e31b05c73c405253397a1e1b5c2c862f
Author:     Michael Meeks <michael.meeks at collabora.com>
AuthorDate: Fri Jun 28 11:18:59 2019 +0100
Commit:     Michael Meeks <michael.meeks at collabora.com>
CommitDate: Thu Oct 3 18:52:29 2019 +0100

    Fatal exceptions need to take the kit process down.
    
    Otherwise the Kit main-loop continues while its event processing thread
    is dead, leaving the client stalled.
    
    Change-Id: I7089ed5b5bd8499623624ffdb84c22cedd80cc7e
